@@ -35,7 +35,7 @@ public abstract class TypingHandler extends KeyPadHandler {
 	@NonNull protected InputType inputType = new InputType(null, null);
 	@NonNull protected TextField textField = new TextField(null, null, null);
 	@NonNull protected TextSelection textSelection = new TextSelection(null, null);
-	@NonNull protected SuggestionOps suggestionOps = new SuggestionOps(null, null, null, null, null, null, null, null);
+	@NonNull protected SuggestionOps suggestionOps = new SuggestionOps(null, null, null, null, null, null, null, null, null);
 
 	@Nullable private Handler suggestionHandler;
 	@Nullable private Handler shiftStateDebounceHandler;
@@ -50,7 +50,7 @@ public abstract class TypingHandler extends KeyPadHandler {
 
 
 	protected void createSuggestionBar() {
-		suggestionOps = new SuggestionOps(this, settings, mainView, appHacks, textField, statusBar, this::onAcceptSuggestionsDelayed, this::onOK);
+		suggestionOps = new SuggestionOps(this, settings, mainView, appHacks, inputType, textField, statusBar, this::onAcceptSuggestionsDelayed, this::onOK);
 	}
 
 
@@ -105,7 +105,7 @@ public abstract class TypingHandler extends KeyPadHandler {
 
 		// changing the TextField and notifying all interested classes is an atomic operation
 		appHacks.setDependencies(inputType, textField, textSelection);
-		suggestionOps.setDependencies(appHacks, textField, statusBar);
+		suggestionOps.setDependencies(appHacks, inputType, textField, statusBar);
 	}
 
 
@@ -350,9 +350,13 @@ public abstract class TypingHandler extends KeyPadHandler {
 		allowedInputModes = new ArrayList<>(inputType.determineInputModes(getApplicationContext()));
 		if (LanguageKind.isJapanese(mLanguage)) {
 			determineJapaneseInputModes();
-		} else if (!mLanguage.hasABC()) {
+		}
+
+		if (!mLanguage.hasABC()) {
 			allowedInputModes.remove((Integer) InputMode.MODE_ABC);
-		} else if (!settings.getPredictiveMode()) {
+		}
+
+		if (!settings.getPredictiveMode()) {
 			allowedInputModes.remove((Integer) InputMode.MODE_PREDICTIVE);
 		}
 
@@ -361,17 +365,14 @@ public abstract class TypingHandler extends KeyPadHandler {
 
 
 	/**
-	 * Since Japanese is unique with its 3 alphabets, we need to setup the input modes separately.
+	 * In Japanese, Hiragana and Katakana modes are the equivalents of ABC mode in other languages.
+	 * So when typing letters is possible (ABC mode allowed), we replace ABC with these two modes.
 	 */
 	private void determineJapaneseInputModes() {
 		if (allowedInputModes.contains(InputMode.MODE_ABC)) {
-			allowedInputModes.remove((Integer) InputMode.MODE_ABC);
 			allowedInputModes.add(InputMode.MODE_HIRAGANA);
 			allowedInputModes.add(InputMode.MODE_KATAKANA);
 		}
-		if (!settings.getPredictiveMode()) {
-			allowedInputModes.remove((Integer) InputMode.MODE_PREDICTIVE);
-		}
 	}
 
 
