@@ -62,13 +62,13 @@ abstract class UiHandler extends AbstractHandler {
 
 	protected void initTray() {
 		mainView.getView();
-		statusBar = new StatusBar(this, settings, mainView.getView(), this::resetStatus).setColorScheme();
+		statusBar = new StatusBar(this, settings, mainView, this::resetStatus).setColorScheme();
 		createSuggestionBar();
 		getSuggestionOps().setColorScheme();
 	}
 
 
-	public void initUi(InputMode inputMode) {
+	protected void initUi(InputMode inputMode) {
 		if (mainView.create()) {
 			initTray();
 			setCurrentView();
@@ -120,7 +120,7 @@ abstract class UiHandler extends AbstractHandler {
 			return;
 		}
 
-		final int resId = new StatusIcon(settings, mode, language, displayTextCase).resourceId;
+		final int resId = new StatusIcon(settings.isStatusIconEnabled() ? mode : null, language, displayTextCase).resourceId;
 		if (resId == 0) {
 			hideStatusIcon();
 		} else {
