@@ -11,6 +11,7 @@ import java.util.ArrayList;
 import java.util.LinkedList;
 
 import io.github.sspanak.tt9.hacks.AppHacks;
+import io.github.sspanak.tt9.hacks.InputType;
 import io.github.sspanak.tt9.languages.Language;
 import io.github.sspanak.tt9.languages.LanguageKind;
 import io.github.sspanak.tt9.preferences.settings.SettingsStore;
@@ -28,15 +29,19 @@ public class SuggestionOps {
 
 	@Nullable protected SuggestionsBar suggestionBar;
 	@Nullable private AppHacks appHacks;
+	private boolean isInputLimited;
 	@NonNull private TextField textField;
+	@Nullable private final SettingsStore settings;
 	@Nullable private StatusBar statusBar;
 
 
-	public SuggestionOps(@Nullable InputMethodService ims, @Nullable SettingsStore settings, @Nullable ResizableMainView mainView, @Nullable AppHacks appHacks, @Nullable TextField textField, @Nullable StatusBar statusBar, @Nullable ConsumerCompat<String> onDelayedAccept, @Nullable Runnable onSuggestionClick) {
+	public SuggestionOps(@Nullable InputMethodService ims, @Nullable SettingsStore settings, @Nullable ResizableMainView mainView, @Nullable AppHacks appHacks, @Nullable InputType inputType, @Nullable TextField textField, @Nullable StatusBar statusBar, @Nullable ConsumerCompat<String> onDelayedAccept, @Nullable Runnable onSuggestionClick) {
 		delayedAcceptHandler = new Handler(Looper.getMainLooper());
 		this.onDelayedAccept = onDelayedAccept != null ? onDelayedAccept : s -> {};
 
 		this.appHacks = appHacks;
+		this.isInputLimited = inputType == null || inputType.isLimited();
+		this.settings = settings;
 		this.statusBar = statusBar;
 		this.textField = textField != null ? textField : new TextField(ims, settings, null);
 
@@ -45,6 +50,7 @@ public class SuggestionOps {
 		}
 	}
 
+
 	public void setLanguage(@Nullable Language newLanguage) {
 		if (suggestionBar != null) {
 			suggestionBar.setRTL(LanguageKind.isRTL(newLanguage));
@@ -52,8 +58,9 @@ public class SuggestionOps {
 	}
 
 
-	public void setDependencies(@NonNull AppHacks appHacks, @NonNull TextField textField, @NonNull StatusBar statusBar) {
+	public void setDependencies(@NonNull AppHacks appHacks, @NonNull InputType inputType, @NonNull TextField textField, @NonNull StatusBar statusBar) {
 		this.appHacks = appHacks;
+		this.isInputLimited = inputType.isLimited();
 		this.textField = textField;
 		this.statusBar = statusBar;
 	}
@@ -87,31 +94,20 @@ public class SuggestionOps {
 
 
 	public void set(ArrayList<String> suggestions) {
-		if (suggestionBar != null) {
-			suggestionBar.setMany(suggestions, 0, false);
-		}
-		if (statusBar != null) {
-			statusBar.setShown(suggestions == null || suggestions.isEmpty());
-		}
+		set(suggestions, 0, false);
 	}
 
+
 	public void set(ArrayList<String> suggestions, boolean containsGenerated) {
-		if (suggestionBar != null) {
-			suggestionBar.setMany(suggestions, 0, containsGenerated);
-		}
-		if (statusBar != null) {
-			statusBar.setShown(suggestions == null || suggestions.isEmpty());
-		}
+		set(suggestions, 0, containsGenerated);
 	}
 
 
 	public void set(ArrayList<String> suggestions, int selectIndex, boolean containsGenerated) {
+		setVisibility(settings, suggestions, false);
 		if (suggestionBar != null) {
 			suggestionBar.setMany(suggestions, selectIndex, containsGenerated);
 		}
-		if (statusBar != null) {
-			statusBar.setShown(suggestions == null || suggestions.isEmpty());
-		}
 	}
 
 
@@ -124,7 +120,10 @@ public class SuggestionOps {
 			}
 		}
 
-		set(clipStrings);
+		setVisibility(settings, clipStrings, true);
+		if (suggestionBar != null) {
+			suggestionBar.setMany(clipStrings, 0, false);
+		}
 	}
 
 
@@ -247,4 +246,17 @@ public class SuggestionOps {
 			suggestionBar.setColorScheme();
 		}
 	}
+
+
+	private void setVisibility(@Nullable SettingsStore settings, @Nullable ArrayList<String> newSuggestions, boolean clipboardSuggestions) {
+		final boolean areSuggestionsVisible = isInputLimited || clipboardSuggestions || (settings != null && settings.getShowSuggestions());
+
+		if (suggestionBar != null) {
+			suggestionBar.setVisible(areSuggestionsVisible);
+		}
+
+		if (statusBar != null) {
+			statusBar.setShown(newSuggestions == null || newSuggestions.isEmpty() || !areSuggestionsVisible);
+		}
+	}
 }
