@@ -1,5 +1,8 @@
 package io.github.sspanak.tt9.ime.modes;
 
+import androidx.annotation.NonNull;
+import androidx.annotation.Nullable;
+
 import io.github.sspanak.tt9.hacks.InputType;
 import io.github.sspanak.tt9.ime.helpers.TextField;
 import io.github.sspanak.tt9.ime.modes.predictions.KanaPredictions;
@@ -7,14 +10,14 @@ import io.github.sspanak.tt9.languages.Language;
 import io.github.sspanak.tt9.preferences.settings.SettingsStore;
 
 public class ModeKatakana extends ModeHiragana {
-	protected ModeKatakana(SettingsStore settings, Language lang, InputType inputType, TextField textField) {
+	protected ModeKatakana(@NonNull SettingsStore settings, @NonNull Language lang, @Nullable InputType inputType, @Nullable TextField textField) {
 		super(settings, lang, inputType, textField);
 		NAME = "カタカナ";
 	}
 
 	@Override
 	protected void initPredictions() {
-		predictions = new KanaPredictions(settings, textField, true);
+		predictions = new KanaPredictions(settings, true);
 		predictions.setWordsChangedHandler(this::onPredictions);
 	}
 
