@@ -19,13 +19,12 @@ public class SpeechRecognizerSupportLegacy {
 	SpeechRecognizerSupportLegacy setLanguage(@Nullable Language l) { return this; }
 
 	boolean isAlternativeAvailable(@NonNull Context context) {
-//		final List<ResolveInfo> resolveInfo = context.getPackageManager().queryIntentActivities(
-//			VoiceInputOps.createIntent(null),
-//			PackageManager.MATCH_DEFAULT_ONLY
-//		);
-//
-//		return resolveInfo.size() > 1;
-		return false;
+		final List<ResolveInfo> resolveInfo = context.getPackageManager().queryIntentActivities(
+			VoiceInputOps.createIntent(null),
+			PackageManager.MATCH_DEFAULT_ONLY
+		);
+
+		return resolveInfo.size() > 1;
 	}
 
 	boolean isGoogleOfflineRecognitionAvailable(@NonNull Context context) {
